# AnsibleExtraVars


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**janus_version** | **str** |  | 
**janus_libwebsockets_version** | **str** |  | 
**janus_libnice_version** | **str** |  | 
**janus_usrsctp_version** | **str** |  | 
**janus_libsrtp_version** | **str** |  | 
**tflite_version** | **str** |  | 
**printnanny_cli_version** | **str** |  | 
**libcamera_version** | **str** |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


